┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/dolphinsettingsdialog.h
diff options
context:
space:
mode:
authorPeter Penz <[email protected]>2008-01-21 16:51:31 +0000
committerPeter Penz <[email protected]>2008-01-21 16:51:31 +0000
commitf3c83ec89f7a50381f86faff5a00781cf1613a6a (patch)
tree44ab7014d397d98ebb53b1e75247977491895997 /src/dolphinsettingsdialog.h
parent8ba61eb0c77221f94b42f2f6a532e70da3d27ccb (diff)
Split the "General Settings" into "Startup Settings" and "General Settings" for having a cleaner layout. Still some fine tuning and code cleanups have to be done...
svn path=/trunk/KDE/kdebase/apps/; revision=764389
Diffstat (limited to 'src/dolphinsettingsdialog.h')
-rw-r--r--src/dolphinsettingsdialog.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/src/dolphinsettingsdialog.h b/src/dolphinsettingsdialog.h
index e68d82798..2cb7fc78e 100644
--- a/src/dolphinsettingsdialog.h
+++ b/src/dolphinsettingsdialog.h
@@ -22,14 +22,16 @@
#define DOLPHINSETTINGSDIALOG_H
#include <kpagedialog.h>
+
class GeneralSettingsPage;
+class StartupSettingsPage;
class ViewSettingsPage;
class DolphinMainWindow;
/**
* @brief Settings dialog for Dolphin.
*
* Contains the pages for general settings and view settings.
*
* @author Peter Penz <[email protected]>
*/
@@ -50,6 +52,7 @@ private:
void restoreDefaults();
private:
+ StartupSettingsPage* m_startupSettingsPage;
GeneralSettingsPage* m_generalSettingsPage;
ViewSettingsPage* m_viewSettingsPage;
};
@@ -22,14 +22,16 @@
* @brief Settings dialog for Dolphin.
*
- * Contains the pages for general settings and view settings.
+ * Contains the pages for startup settings, general settings and view settings.
*
* @author Peter Penz <[email protected]>